=======
History
=======

0.1.2 (2018-07-14)
------------------

* Fix an asine bug in the docs


0.1.1 (2018-07-14)
------------------

* Added tests for session and formats modules
* Fixed mispelled PgnHandler class (!)
* Fixed issue with trailing whitespace when splitting multiple PGN texts
* Fixed the usage overview in the README
* Fixed the versions for travis-ci
* Made it easier to test the `JsonHandler` class
* Salted the bumpversion config to taste


0.1.0 (2018-07-10)
------------------

* First release on PyPI.
